@@ -1,6 +1,6 @@
 {
     'name': "Odoo La Feixa customizations",
-    'version': '12.0.0.0.29',
+    'version': '12.0.0.0.33',
     'depends': ['easy_my_coop_es'],
     'author': "Coopdevs Treball SCCL",
     'website': 'https://coopdevs.org',
@@ -14,6 +14,7 @@
         "views/become_cooperator_view.xml",
         "views/subscription_request_view.xml",
         "views/res_company_view.xml",
-        "views/cooperator_thanks_view.xml"
+        "views/cooperator_thanks_view.xml",
+        "views/purchase_order_view.xml"
     ],
 }
